@@ -16,6 +16,7 @@
 #include <KAboutData>
 #include <KDBusService>
 #include <KLocalizedString>
+#include <KWindowSystem>
 
 int main(int argc, char *argv[])
 {
@@ -56,7 +57,8 @@ int main(int argc, char *argv[])
     BlueWizard *wizard = new BlueWizard;
 
     QObject::connect(&service, &KDBusService::activateRequested, wizard, [wizard]() {
-        wizard->setWindowState((wizard->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
+        KWindowSystem::updateStartupId(wizard->windowHandle());
+        KWindowSystem::activateWindow(wizard->windowHandle());
     });
 
     return app.exec();
